﻿namespace FileSystem
{
    internal class Program
    {
        private const int NumberOfInterestingDirectories = 5;
        private const int NumberOfInterestingFiles = 5;
        private const string InterestingFolder = @"c:\Windows";

        static void Main()
        {
            // Вывод информации о всех дисках
            Console.WriteLine("Информация обо всех дисках:\n");

            PrintAllDriveProperties();

            WaitUntilEnter();


            // Вывод информации о директории InterestingFolder (c:\Windows)
            Console.WriteLine($"Информация о директории {InterestingFolder}:");

            DirectoryInfo folder = new DirectoryInfo(InterestingFolder);
            PrintFolderProperties(folder);

            WaitUntilEnter();


            // Вывод информации о первых NumberOfInterestingDirectories (5) поддиректорий InterestingFolder (c:\Windows)
            Console.WriteLine($"Информация о первых {NumberOfInterestingDirectories} поддиректориях папки {InterestingFolder}:\n");

            DirectoryInfo[] subFolders = folder.GetDirectories();
            for (int i = 0; i < subFolders.Length && i < NumberOfInterestingDirectories; i++)
            {
                PrintFolderProperties(subFolders[i]);
            }

            WaitUntilEnter();


            // Вывод информации о первых NumberOfInterestingFiles (5) .log файлах из папки InterestingFolder (c:\Windows)
            Console.WriteLine($"Информация о первых {NumberOfInterestingFiles} .log файлах из папки {InterestingFolder}:\n");

            FileInfo[] filesInFolder = folder.GetFiles("*.log", SearchOption.TopDirectoryOnly);
            for (int i = 0; i < filesInFolder.Length && i < NumberOfInterestingFiles; i++)
            {
                PrintFileProperties(filesInFolder[i]);
            }

            WaitUntilEnter();
        }


        /// <summary>
        /// Выводит информацию о всех дисках
        /// </summary>
        private static void PrintAllDriveProperties()
        {
            DriveInfo[] drives = DriveInfo.GetDrives(); // Получение всех дисков
            foreach (DriveInfo d in drives)
            {
                Console.WriteLine("Name: {0}", d.Name);
                Console.WriteLine("Drive Type: {0}", d.DriveType);
                Console.WriteLine("Is Ready: {0}", d.IsReady);
                if (d.IsReady)
                {
                    Console.WriteLine("Volume Label: {0}", d.VolumeLabel);
                    Console.WriteLine("Drive Format: {0}", d.DriveFormat);
                    Console.WriteLine("Total Size: {0}", d.TotalSize);
                    Console.WriteLine("Available Free Space: {0}", d.AvailableFreeSpace);
                }
                Console.WriteLine();
            }
        }


        /// <summary>
        /// Выводит информацию о папке
        /// </summary>
        /// <param name="folder">Папка</param>
        private static void PrintFolderProperties(DirectoryInfo folder)
        {
            Console.WriteLine("Name: {0}", folder.Name);
            Console.WriteLine("Attributes: {0}", folder.Attributes);
            Console.WriteLine("Creation Time: {0}", folder.CreationTime);
            Console.WriteLine("Full Name: {0}{1}", folder.FullName, Environment.NewLine);
        }


        /// <summary>
        /// Выводит некоторую информацию о файле
        /// </summary>
        /// <param name="file">Файл</param>
        private static void PrintFileProperties(FileInfo file)
        {
            Console.WriteLine("Name: {0}", file.Name);
            Console.WriteLine("Attributes: {0}", file.Attributes);
            Console.WriteLine("Creation Time: {0}", file.CreationTime);
            Console.WriteLine("Length: {0}", file.Length);
            Console.WriteLine("Extension: {0}", file.Extension);
            Console.WriteLine("Full Name: {0}{1}", file.FullName, Environment.NewLine);
        }


        private static void WaitUntilEnter()
        {
            Console.WriteLine("Нажмите ENTER, чтобы продолжить\n");
            Console.ReadLine();
        }
    }
}